# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow/contrib/rpc/python/kernel_tests/test_example.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow/contrib/rpc/python/kernel_tests/test_example.proto',
  package='tensorflow.contrib.rpc',
  syntax='proto2',
  serialized_pb=_b('\n=tensorflow/contrib/rpc/python/kernel_tests/test_example.proto\x12\x16tensorflow.contrib.rpc\x1a%tensorflow/core/framework/types.proto\"\x9d\x01\n\x08TestCase\x12\x41\n\tprimitive\x18\x01 \x03(\x0b\x32..tensorflow.contrib.rpc.RepeatedPrimitiveValue\x12\r\n\x05shape\x18\x02 \x03(\x05\x12\r\n\x05sizes\x18\x03 \x03(\x05\x12\x30\n\x05\x66ield\x18\x04 \x03(\x0b\x32!.tensorflow.contrib.rpc.FieldSpec\"\x80\x01\n\tFieldSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05\x64type\x18\x02 \x01(\x0e\x32\x14.tensorflow.DataType\x12@\n\x08\x65xpected\x18\x03 \x01(\x0b\x32..tensorflow.contrib.rpc.RepeatedPrimitiveValue\"\xe0\x02\n\tTestValue\x12?\n\x0fprimitive_value\x18\x01 \x01(\x0b\x32&.tensorflow.contrib.rpc.PrimitiveValue\x12\x35\n\nenum_value\x18\x02 \x01(\x0b\x32!.tensorflow.contrib.rpc.EnumValue\x12;\n\rmessage_value\x18\x03 \x01(\x0b\x32$.tensorflow.contrib.rpc.MessageValue\x12L\n\x16repeated_message_value\x18\x04 \x01(\x0b\x32,.tensorflow.contrib.rpc.RepeatedMessageValue\x12P\n\x18repeated_primitive_value\x18\x06 \x01(\x0b\x32..tensorflow.contrib.rpc.RepeatedPrimitiveValue\"\xda\x02\n\x0ePrimitiveValue\x12\x14\n\x0c\x64ouble_value\x18\x01 \x01(\x01\x12\x13\n\x0b\x66loat_value\x18\x02 \x01(\x02\x12\x13\n\x0bint64_value\x18\x03 \x01(\x03\x12\x14\n\x0cuint64_value\x18\x04 \x01(\x04\x12\x13\n\x0bint32_value\x18\x05 \x01(\x05\x12\x15\n\rfixed64_value\x18\x06 \x01(\x06\x12\x15\n\rfixed32_value\x18\x07 \x01(\x07\x12\x12\n\nbool_value\x18\x08 \x01(\x08\x12\x14\n\x0cstring_value\x18\t \x01(\t\x12\x13\n\x0b\x62ytes_value\x18\x0c \x01(\x0c\x12\x14\n\x0cuint32_value\x18\r \x01(\r\x12\x16\n\x0esfixed32_value\x18\x0f \x01(\x0f\x12\x16\n\x0esfixed64_value\x18\x10 \x01(\x10\x12\x14\n\x0csint32_value\x18\x11 \x01(\x11\x12\x14\n\x0csint64_value\x18\x12 \x01(\x12\"\xa1\x03\n\x16RepeatedPrimitiveValue\x12\x14\n\x0c\x64ouble_value\x18\x01 \x03(\x01\x12\x13\n\x0b\x66loat_value\x18\x02 \x03(\x02\x12\x13\n\x0bint64_value\x18\x03 \x03(\x03\x12\x14\n\x0cuint64_value\x18\x04 \x03(\x04\x12\x13\n\x0bint32_value\x18\x05 \x03(\x05\x12\x15\n\rfixed64_value\x18\x06 \x03(\x06\x12\x15\n\rfixed32_value\x18\x07 \x03(\x07\x12\x12\n\nbool_value\x18\x08 \x03(\x08\x12\x14\n\x0cstring_value\x18\t \x03(\t\x12\x13\n\x0b\x62ytes_value\x18\x0c \x03(\x0c\x12\x14\n\x0cuint32_value\x18\r \x03(\r\x12\x16\n\x0esfixed32_value\x18\x0f \x03(\x0f\x12\x16\n\x0esfixed64_value\x18\x10 \x03(\x10\x12\x14\n\x0csint32_value\x18\x11 \x03(\x11\x12\x14\n\x0csint64_value\x18\x12 \x03(\x12\x12=\n\rmessage_value\x18\x13 \x03(\x0b\x32&.tensorflow.contrib.rpc.PrimitiveValue\"\xd3\x03\n\x14PackedPrimitiveValue\x12\x18\n\x0c\x64ouble_value\x18\x01 \x03(\x01\x42\x02\x10\x01\x12\x17\n\x0b\x66loat_value\x18\x02 \x03(\x02\x42\x02\x10\x01\x12\x17\n\x0bint64_value\x18\x03 \x03(\x03\x42\x02\x10\x01\x12\x18\n\x0cuint64_value\x18\x04 \x03(\x04\x42\x02\x10\x01\x12\x17\n\x0bint32_value\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\x19\n\rfixed64_value\x18\x06 \x03(\x06\x42\x02\x10\x01\x12\x19\n\rfixed32_value\x18\x07 \x03(\x07\x42\x02\x10\x01\x12\x16\n\nbool_value\x18\x08 \x03(\x08\x42\x02\x10\x01\x12\x14\n\x0cstring_value\x18\t \x03(\t\x12\x13\n\x0b\x62ytes_value\x18\x0c \x03(\x0c\x12\x18\n\x0cuint32_value\x18\r \x03(\rB\x02\x10\x01\x12\x1a\n\x0esfixed32_value\x18\x0f \x03(\x0f\x42\x02\x10\x01\x12\x1a\n\x0esfixed64_value\x18\x10 \x03(\x10\x42\x02\x10\x01\x12\x18\n\x0csint32_value\x18\x11 \x03(\x11\x42\x02\x10\x01\x12\x18\n\x0csint64_value\x18\x12 \x03(\x12\x42\x02\x10\x01\x12=\n\rmessage_value\x18\x13 \x03(\x0b\x32&.tensorflow.contrib.rpc.PrimitiveValue\"\xe5\x01\n\tEnumValue\x12;\n\nenum_value\x18\x0e \x01(\x0e\x32\'.tensorflow.contrib.rpc.EnumValue.Color\x12\x44\n\x13repeated_enum_value\x18\x0f \x03(\x0e\x32\'.tensorflow.contrib.rpc.EnumValue.Color\"U\n\x05\x43olor\x12\x07\n\x03RED\x10\x00\x12\n\n\x06ORANGE\x10\x01\x12\n\n\x06YELLOW\x10\x02\x12\t\n\x05GREEN\x10\x03\x12\x08\n\x04\x42LUE\x10\x04\x12\n\n\x06INDIGO\x10\x05\x12\n\n\x06VIOLET\x10\x06\">\n\x11InnerMessageValue\x12\x13\n\x0b\x66loat_value\x18\x02 \x01(\x02\x12\x14\n\x0c\x62ytes_values\x18\x08 \x03(\x0c\"\x82\x01\n\x12MiddleMessageValue\x12\x14\n\x0cint32_values\x18\x05 \x03(\x05\x12@\n\rmessage_value\x18\x0b \x01(\x0b\x32).tensorflow.contrib.rpc.InnerMessageValue\x12\x14\n\x0cuint32_value\x18\r \x01(\r\"g\n\x0cMessageValue\x12\x14\n\x0c\x64ouble_value\x18\x01 \x01(\x01\x12\x41\n\rmessage_value\x18\x0b \x01(\x0b\x32*.tensorflow.contrib.rpc.MiddleMessageValue\"\xb0\x01\n\x14RepeatedMessageValue\x12W\n\x0emessage_values\x18\x0b \x03(\x0b\x32?.tensorflow.contrib.rpc.RepeatedMessageValue.NestedMessageValue\x1a?\n\x12NestedMessageValue\x12\x13\n\x0b\x66loat_value\x18\x02 \x01(\x02\x12\x14\n\x0c\x62ytes_values\x18\x08 \x03(\x0c\"9\n\x0b\x45xtraFields\x12\x15\n\x0cstring_value\x18\xf0\r \x01(\t\x12\x13\n\nbool_value\x18\xf1\r \x01(\x08\x32\xf4\x03\n\x0fTestCaseService\x12[\n\x13IncrementTestShapes\x12 .tensorflow.contrib.rpc.TestCase\x1a .tensorflow.contrib.rpc.TestCase\"\x00\x12T\n\x0cSleepForever\x12 .tensorflow.contrib.rpc.TestCase\x1a .tensorflow.contrib.rpc.TestCase\"\x00\x12]\n\x15SometimesSleepForever\x12 .tensorflow.contrib.rpc.TestCase\x1a .tensorflow.contrib.rpc.TestCase\"\x00\x12\x65\n\x1d\x41lwaysFailWithInvalidArgument\x12 .tensorflow.contrib.rpc.TestCase\x1a .tensorflow.contrib.rpc.TestCase\"\x00\x12h\n SometimesFailWithInvalidArgument\x12 .tensorflow.contrib.rpc.TestCase\x1a .tensorflow.contrib.rpc.TestCase\"\x00')
  ,
  dependencies=[tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR,])



_ENUMVALUE_COLOR = _descriptor.EnumDescriptor(
  name='Color',
  full_name='tensorflow.contrib.rpc.EnumValue.Color',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORANGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INDIGO', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIOLET', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2158,
  serialized_end=2243,
)
_sym_db.RegisterEnumDescriptor(_ENUMVALUE_COLOR)


_TESTCASE = _descriptor.Descriptor(
  name='TestCase',
  full_name='tensorflow.contrib.rpc.TestCase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive', full_name='tensorflow.contrib.rpc.TestCase.primitive', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='tensorflow.contrib.rpc.TestCase.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizes', full_name='tensorflow.contrib.rpc.TestCase.sizes', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='tensorflow.contrib.rpc.TestCase.field', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=286,
)


_FIELDSPEC = _descriptor.Descriptor(
  name='FieldSpec',
  full_name='tensorflow.contrib.rpc.FieldSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorflow.contrib.rpc.FieldSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='tensorflow.contrib.rpc.FieldSpec.dtype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expected', full_name='tensorflow.contrib.rpc.FieldSpec.expected', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=417,
)


_TESTVALUE = _descriptor.Descriptor(
  name='TestValue',
  full_name='tensorflow.contrib.rpc.TestValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive_value', full_name='tensorflow.contrib.rpc.TestValue.primitive_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_value', full_name='tensorflow.contrib.rpc.TestValue.enum_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='tensorflow.contrib.rpc.TestValue.message_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeated_message_value', full_name='tensorflow.contrib.rpc.TestValue.repeated_message_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeated_primitive_value', full_name='tensorflow.contrib.rpc.TestValue.repeated_primitive_value', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=772,
)


_PRIMITIVEVALUE = _descriptor.Descriptor(
  name='PrimitiveValue',
  full_name='tensorflow.contrib.rpc.PrimitiveValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.float_value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.int64_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.uint64_value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.int32_value', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed64_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.fixed64_value', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed32_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.fixed32_value', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.bool_value', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.string_value', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.bytes_value', index=9,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.uint32_value', index=10,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sfixed32_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.sfixed32_value', index=11,
      number=15, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sfixed64_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.sfixed64_value', index=12,
      number=16, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint32_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.sint32_value', index=13,
      number=17, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint64_value', full_name='tensorflow.contrib.rpc.PrimitiveValue.sint64_value', index=14,
      number=18, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=1121,
)


_REPEATEDPRIMITIVEVALUE = _descriptor.Descriptor(
  name='RepeatedPrimitiveValue',
  full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.float_value', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.int64_value', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.uint64_value', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.int32_value', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed64_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.fixed64_value', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed32_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.fixed32_value', index=6,
      number=7, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.bool_value', index=7,
      number=8, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.string_value', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.bytes_value', index=9,
      number=12, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.uint32_value', index=10,
      number=13, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sfixed32_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.sfixed32_value', index=11,
      number=15, type=15, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sfixed64_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.sfixed64_value', index=12,
      number=16, type=16, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint32_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.sint32_value', index=13,
      number=17, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint64_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.sint64_value', index=14,
      number=18, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='tensorflow.contrib.rpc.RepeatedPrimitiveValue.message_value', index=15,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1541,
)


_PACKEDPRIMITIVEVALUE = _descriptor.Descriptor(
  name='PackedPrimitiveValue',
  full_name='tensorflow.contrib.rpc.PackedPrimitiveValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.float_value', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.int64_value', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.uint64_value', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.int32_value', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed64_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.fixed64_value', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed32_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.fixed32_value', index=6,
      number=7, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.bool_value', index=7,
      number=8, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.string_value', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.bytes_value', index=9,
      number=12, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.uint32_value', index=10,
      number=13, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sfixed32_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.sfixed32_value', index=11,
      number=15, type=15, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sfixed64_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.sfixed64_value', index=12,
      number=16, type=16, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint32_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.sint32_value', index=13,
      number=17, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint64_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.sint64_value', index=14,
      number=18, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='tensorflow.contrib.rpc.PackedPrimitiveValue.message_value', index=15,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=2011,
)


_ENUMVALUE = _descriptor.Descriptor(
  name='EnumValue',
  full_name='tensorflow.contrib.rpc.EnumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enum_value', full_name='tensorflow.contrib.rpc.EnumValue.enum_value', index=0,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeated_enum_value', full_name='tensorflow.contrib.rpc.EnumValue.repeated_enum_value', index=1,
      number=15, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENUMVALUE_COLOR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2014,
  serialized_end=2243,
)


_INNERMESSAGEVALUE = _descriptor.Descriptor(
  name='InnerMessageValue',
  full_name='tensorflow.contrib.rpc.InnerMessageValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='float_value', full_name='tensorflow.contrib.rpc.InnerMessageValue.float_value', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_values', full_name='tensorflow.contrib.rpc.InnerMessageValue.bytes_values', index=1,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2245,
  serialized_end=2307,
)


_MIDDLEMESSAGEVALUE = _descriptor.Descriptor(
  name='MiddleMessageValue',
  full_name='tensorflow.contrib.rpc.MiddleMessageValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='int32_values', full_name='tensorflow.contrib.rpc.MiddleMessageValue.int32_values', index=0,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='tensorflow.contrib.rpc.MiddleMessageValue.message_value', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32_value', full_name='tensorflow.contrib.rpc.MiddleMessageValue.uint32_value', index=2,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2310,
  serialized_end=2440,
)


_MESSAGEVALUE = _descriptor.Descriptor(
  name='MessageValue',
  full_name='tensorflow.contrib.rpc.MessageValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='tensorflow.contrib.rpc.MessageValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='tensorflow.contrib.rpc.MessageValue.message_value', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2442,
  serialized_end=2545,
)


_REPEATEDMESSAGEVALUE_NESTEDMESSAGEVALUE = _descriptor.Descriptor(
  name='NestedMessageValue',
  full_name='tensorflow.contrib.rpc.RepeatedMessageValue.NestedMessageValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='float_value', full_name='tensorflow.contrib.rpc.RepeatedMessageValue.NestedMessageValue.float_value', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_values', full_name='tensorflow.contrib.rpc.RepeatedMessageValue.NestedMessageValue.bytes_values', index=1,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2661,
  serialized_end=2724,
)

_REPEATEDMESSAGEVALUE = _descriptor.Descriptor(
  name='RepeatedMessageValue',
  full_name='tensorflow.contrib.rpc.RepeatedMessageValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_values', full_name='tensorflow.contrib.rpc.RepeatedMessageValue.message_values', index=0,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REPEATEDMESSAGEVALUE_NESTEDMESSAGEVALUE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2548,
  serialized_end=2724,
)


_EXTRAFIELDS = _descriptor.Descriptor(
  name='ExtraFields',
  full_name='tensorflow.contrib.rpc.ExtraFields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='tensorflow.contrib.rpc.ExtraFields.string_value', index=0,
      number=1776, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='tensorflow.contrib.rpc.ExtraFields.bool_value', index=1,
      number=1777, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2783,
)

_TESTCASE.fields_by_name['primitive'].message_type = _REPEATEDPRIMITIVEVALUE
_TESTCASE.fields_by_name['field'].message_type = _FIELDSPEC
_FIELDSPEC.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_FIELDSPEC.fields_by_name['expected'].message_type = _REPEATEDPRIMITIVEVALUE
_TESTVALUE.fields_by_name['primitive_value'].message_type = _PRIMITIVEVALUE
_TESTVALUE.fields_by_name['enum_value'].message_type = _ENUMVALUE
_TESTVALUE.fields_by_name['message_value'].message_type = _MESSAGEVALUE
_TESTVALUE.fields_by_name['repeated_message_value'].message_type = _REPEATEDMESSAGEVALUE
_TESTVALUE.fields_by_name['repeated_primitive_value'].message_type = _REPEATEDPRIMITIVEVALUE
_REPEATEDPRIMITIVEVALUE.fields_by_name['message_value'].message_type = _PRIMITIVEVALUE
_PACKEDPRIMITIVEVALUE.fields_by_name['message_value'].message_type = _PRIMITIVEVALUE
_ENUMVALUE.fields_by_name['enum_value'].enum_type = _ENUMVALUE_COLOR
_ENUMVALUE.fields_by_name['repeated_enum_value'].enum_type = _ENUMVALUE_COLOR
_ENUMVALUE_COLOR.containing_type = _ENUMVALUE
_MIDDLEMESSAGEVALUE.fields_by_name['message_value'].message_type = _INNERMESSAGEVALUE
_MESSAGEVALUE.fields_by_name['message_value'].message_type = _MIDDLEMESSAGEVALUE
_REPEATEDMESSAGEVALUE_NESTEDMESSAGEVALUE.containing_type = _REPEATEDMESSAGEVALUE
_REPEATEDMESSAGEVALUE.fields_by_name['message_values'].message_type = _REPEATEDMESSAGEVALUE_NESTEDMESSAGEVALUE
DESCRIPTOR.message_types_by_name['TestCase'] = _TESTCASE
DESCRIPTOR.message_types_by_name['FieldSpec'] = _FIELDSPEC
DESCRIPTOR.message_types_by_name['TestValue'] = _TESTVALUE
DESCRIPTOR.message_types_by_name['PrimitiveValue'] = _PRIMITIVEVALUE
DESCRIPTOR.message_types_by_name['RepeatedPrimitiveValue'] = _REPEATEDPRIMITIVEVALUE
DESCRIPTOR.message_types_by_name['PackedPrimitiveValue'] = _PACKEDPRIMITIVEVALUE
DESCRIPTOR.message_types_by_name['EnumValue'] = _ENUMVALUE
DESCRIPTOR.message_types_by_name['InnerMessageValue'] = _INNERMESSAGEVALUE
DESCRIPTOR.message_types_by_name['MiddleMessageValue'] = _MIDDLEMESSAGEVALUE
DESCRIPTOR.message_types_by_name['MessageValue'] = _MESSAGEVALUE
DESCRIPTOR.message_types_by_name['RepeatedMessageValue'] = _REPEATEDMESSAGEVALUE
DESCRIPTOR.message_types_by_name['ExtraFields'] = _EXTRAFIELDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TestCase = _reflection.GeneratedProtocolMessageType('TestCase', (_message.Message,), dict(
  DESCRIPTOR = _TESTCASE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.TestCase)
  ))
_sym_db.RegisterMessage(TestCase)

FieldSpec = _reflection.GeneratedProtocolMessageType('FieldSpec', (_message.Message,), dict(
  DESCRIPTOR = _FIELDSPEC,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.FieldSpec)
  ))
_sym_db.RegisterMessage(FieldSpec)

TestValue = _reflection.GeneratedProtocolMessageType('TestValue', (_message.Message,), dict(
  DESCRIPTOR = _TESTVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.TestValue)
  ))
_sym_db.RegisterMessage(TestValue)

PrimitiveValue = _reflection.GeneratedProtocolMessageType('PrimitiveValue', (_message.Message,), dict(
  DESCRIPTOR = _PRIMITIVEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.PrimitiveValue)
  ))
_sym_db.RegisterMessage(PrimitiveValue)

RepeatedPrimitiveValue = _reflection.GeneratedProtocolMessageType('RepeatedPrimitiveValue', (_message.Message,), dict(
  DESCRIPTOR = _REPEATEDPRIMITIVEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.RepeatedPrimitiveValue)
  ))
_sym_db.RegisterMessage(RepeatedPrimitiveValue)

PackedPrimitiveValue = _reflection.GeneratedProtocolMessageType('PackedPrimitiveValue', (_message.Message,), dict(
  DESCRIPTOR = _PACKEDPRIMITIVEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.PackedPrimitiveValue)
  ))
_sym_db.RegisterMessage(PackedPrimitiveValue)

EnumValue = _reflection.GeneratedProtocolMessageType('EnumValue', (_message.Message,), dict(
  DESCRIPTOR = _ENUMVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.EnumValue)
  ))
_sym_db.RegisterMessage(EnumValue)

InnerMessageValue = _reflection.GeneratedProtocolMessageType('InnerMessageValue', (_message.Message,), dict(
  DESCRIPTOR = _INNERMESSAGEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.InnerMessageValue)
  ))
_sym_db.RegisterMessage(InnerMessageValue)

MiddleMessageValue = _reflection.GeneratedProtocolMessageType('MiddleMessageValue', (_message.Message,), dict(
  DESCRIPTOR = _MIDDLEMESSAGEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.MiddleMessageValue)
  ))
_sym_db.RegisterMessage(MiddleMessageValue)

MessageValue = _reflection.GeneratedProtocolMessageType('MessageValue', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.MessageValue)
  ))
_sym_db.RegisterMessage(MessageValue)

RepeatedMessageValue = _reflection.GeneratedProtocolMessageType('RepeatedMessageValue', (_message.Message,), dict(

  NestedMessageValue = _reflection.GeneratedProtocolMessageType('NestedMessageValue', (_message.Message,), dict(
    DESCRIPTOR = _REPEATEDMESSAGEVALUE_NESTEDMESSAGEVALUE,
    __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
    # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.RepeatedMessageValue.NestedMessageValue)
    ))
  ,
  DESCRIPTOR = _REPEATEDMESSAGEVALUE,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.RepeatedMessageValue)
  ))
_sym_db.RegisterMessage(RepeatedMessageValue)
_sym_db.RegisterMessage(RepeatedMessageValue.NestedMessageValue)

ExtraFields = _reflection.GeneratedProtocolMessageType('ExtraFields', (_message.Message,), dict(
  DESCRIPTOR = _EXTRAFIELDS,
  __module__ = 'tensorflow.contrib.rpc.python.kernel_tests.test_example_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.contrib.rpc.ExtraFields)
  ))
_sym_db.RegisterMessage(ExtraFields)


_PACKEDPRIMITIVEVALUE.fields_by_name['double_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['double_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['float_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['float_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['int64_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['int64_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['uint64_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['uint64_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['int32_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['int32_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['fixed64_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['fixed64_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['fixed32_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['fixed32_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['bool_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['bool_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['uint32_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['uint32_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['sfixed32_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['sfixed32_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['sfixed64_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['sfixed64_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['sint32_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['sint32_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_PACKEDPRIMITIVEVALUE.fields_by_name['sint64_value'].has_options = True
_PACKEDPRIMITIVEVALUE.fields_by_name['sint64_value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))

_TESTCASESERVICE = _descriptor.ServiceDescriptor(
  name='TestCaseService',
  full_name='tensorflow.contrib.rpc.TestCaseService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=2786,
  serialized_end=3286,
  methods=[
  _descriptor.MethodDescriptor(
    name='IncrementTestShapes',
    full_name='tensorflow.contrib.rpc.TestCaseService.IncrementTestShapes',
    index=0,
    containing_service=None,
    input_type=_TESTCASE,
    output_type=_TESTCASE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SleepForever',
    full_name='tensorflow.contrib.rpc.TestCaseService.SleepForever',
    index=1,
    containing_service=None,
    input_type=_TESTCASE,
    output_type=_TESTCASE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SometimesSleepForever',
    full_name='tensorflow.contrib.rpc.TestCaseService.SometimesSleepForever',
    index=2,
    containing_service=None,
    input_type=_TESTCASE,
    output_type=_TESTCASE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AlwaysFailWithInvalidArgument',
    full_name='tensorflow.contrib.rpc.TestCaseService.AlwaysFailWithInvalidArgument',
    index=3,
    containing_service=None,
    input_type=_TESTCASE,
    output_type=_TESTCASE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SometimesFailWithInvalidArgument',
    full_name='tensorflow.contrib.rpc.TestCaseService.SometimesFailWithInvalidArgument',
    index=4,
    containing_service=None,
    input_type=_TESTCASE,
    output_type=_TESTCASE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTCASESERVICE)

DESCRIPTOR.services_by_name['TestCaseService'] = _TESTCASESERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow/core/framework/graph_transfer_info.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow/core/framework/graph_transfer_info.proto',
  package='tensorflow',
  syntax='proto3',
  serialized_pb=_b('\n3tensorflow/core/framework/graph_transfer_info.proto\x12\ntensorflow\x1a%tensorflow/core/framework/types.proto\">\n\x16GraphTransferNodeInput\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x13\n\x0boutput_port\x18\x02 \x01(\x05\"\x9b\x01\n\x15GraphTransferNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\x05\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12\x11\n\tsoc_op_id\x18\x04 \x01(\x05\x12\x12\n\npadding_id\x18\x05 \x01(\x05\x12\x13\n\x0binput_count\x18\x06 \x01(\x05\x12\x14\n\x0coutput_count\x18\x07 \x01(\x05\"}\n\x1aGraphTransferConstNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\x05\x12\r\n\x05shape\x18\x03 \x03(\x03\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12#\n\x05\x64type\x18\x05 \x01(\x0e\x32\x14.tensorflow.DataType\"e\n\x1aGraphTransferNodeInputInfo\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x36\n\nnode_input\x18\x02 \x03(\x0b\x32\".tensorflow.GraphTransferNodeInput\"E\n\x1bGraphTransferNodeOutputInfo\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x15\n\rmax_byte_size\x18\x02 \x03(\x05\"c\n\x1fGraphTransferGraphInputNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x03\x12#\n\x05\x64type\x18\x03 \x01(\x0e\x32\x14.tensorflow.DataType\"d\n GraphTransferGraphOutputNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x03\x12#\n\x05\x64type\x18\x03 \x01(\x0e\x32\x14.tensorflow.DataType\"\x8d\x04\n\x11GraphTransferInfo\x12\x34\n\tnode_info\x18\x01 \x03(\x0b\x32!.tensorflow.GraphTransferNodeInfo\x12?\n\x0f\x63onst_node_info\x18\x02 \x03(\x0b\x32&.tensorflow.GraphTransferConstNodeInfo\x12?\n\x0fnode_input_info\x18\x03 \x03(\x0b\x32&.tensorflow.GraphTransferNodeInputInfo\x12\x41\n\x10node_output_info\x18\x04 \x03(\x0b\x32\'.tensorflow.GraphTransferNodeOutputInfo\x12J\n\x15graph_input_node_info\x18\x05 \x03(\x0b\x32+.tensorflow.GraphTransferGraphInputNodeInfo\x12L\n\x16graph_output_node_info\x18\x06 \x03(\x0b\x32,.tensorflow.GraphTransferGraphOutputNodeInfo\x12>\n\x0b\x64\x65stination\x18\x07 \x01(\x0e\x32).tensorflow.GraphTransferInfo.Destination\"#\n\x0b\x44\x65stination\x12\x07\n\x03NOP\x10\x00\x12\x0b\n\x07HEXAGON\x10\x01\x42v\n\x18org.tensorflow.frameworkB\x16GraphTransferInfoProtoP\x01Z=github.com/tensorflow/tensorflow/tensorflow/go/core/framework\xf8\x01\x01\x62\x06proto3')
  ,
  dependencies=[tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR,])



_GRAPHTRANSFERINFO_DESTINATION = _descriptor.EnumDescriptor(
  name='Destination',
  full_name='tensorflow.GraphTransferInfo.Destination',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEXAGON', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1323,
  serialized_end=1358,
)
_sym_db.RegisterEnumDescriptor(_GRAPHTRANSFERINFO_DESTINATION)


_GRAPHTRANSFERNODEINPUT = _descriptor.Descriptor(
  name='GraphTransferNodeInput',
  full_name='tensorflow.GraphTransferNodeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='tensorflow.GraphTransferNodeInput.node_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_port', full_name='tensorflow.GraphTransferNodeInput.output_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=168,
)


_GRAPHTRANSFERNODEINFO = _descriptor.Descriptor(
  name='GraphTransferNodeInfo',
  full_name='tensorflow.GraphTransferNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorflow.GraphTransferNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='tensorflow.GraphTransferNodeInfo.node_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='tensorflow.GraphTransferNodeInfo.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soc_op_id', full_name='tensorflow.GraphTransferNodeInfo.soc_op_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_id', full_name='tensorflow.GraphTransferNodeInfo.padding_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_count', full_name='tensorflow.GraphTransferNodeInfo.input_count', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_count', full_name='tensorflow.GraphTransferNodeInfo.output_count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=326,
)


_GRAPHTRANSFERCONSTNODEINFO = _descriptor.Descriptor(
  name='GraphTransferConstNodeInfo',
  full_name='tensorflow.GraphTransferConstNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorflow.GraphTransferConstNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='tensorflow.GraphTransferConstNodeInfo.node_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='tensorflow.GraphTransferConstNodeInfo.shape', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='tensorflow.GraphTransferConstNodeInfo.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='tensorflow.GraphTransferConstNodeInfo.dtype', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=453,
)


_GRAPHTRANSFERNODEINPUTINFO = _descriptor.Descriptor(
  name='GraphTransferNodeInputInfo',
  full_name='tensorflow.GraphTransferNodeInputInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='tensorflow.GraphTransferNodeInputInfo.node_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_input', full_name='tensorflow.GraphTransferNodeInputInfo.node_input', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=556,
)


_GRAPHTRANSFERNODEOUTPUTINFO = _descriptor.Descriptor(
  name='GraphTransferNodeOutputInfo',
  full_name='tensorflow.GraphTransferNodeOutputInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='tensorflow.GraphTransferNodeOutputInfo.node_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_byte_size', full_name='tensorflow.GraphTransferNodeOutputInfo.max_byte_size', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=627,
)


_GRAPHTRANSFERGRAPHINPUTNODEINFO = _descriptor.Descriptor(
  name='GraphTransferGraphInputNodeInfo',
  full_name='tensorflow.GraphTransferGraphInputNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorflow.GraphTransferGraphInputNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='tensorflow.GraphTransferGraphInputNodeInfo.shape', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='tensorflow.GraphTransferGraphInputNodeInfo.dtype', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=728,
)


_GRAPHTRANSFERGRAPHOUTPUTNODEINFO = _descriptor.Descriptor(
  name='GraphTransferGraphOutputNodeInfo',
  full_name='tensorflow.GraphTransferGraphOutputNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorflow.GraphTransferGraphOutputNodeInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='tensorflow.GraphTransferGraphOutputNodeInfo.shape', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='tensorflow.GraphTransferGraphOutputNodeInfo.dtype', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=830,
)


_GRAPHTRANSFERINFO = _descriptor.Descriptor(
  name='GraphTransferInfo',
  full_name='tensorflow.GraphTransferInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_info', full_name='tensorflow.GraphTransferInfo.node_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='const_node_info', full_name='tensorflow.GraphTransferInfo.const_node_info', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_input_info', full_name='tensorflow.GraphTransferInfo.node_input_info', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_output_info', full_name='tensorflow.GraphTransferInfo.node_output_info', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_input_node_info', full_name='tensorflow.GraphTransferInfo.graph_input_node_info', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_output_node_info', full_name='tensorflow.GraphTransferInfo.graph_output_node_info', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='tensorflow.GraphTransferInfo.destination', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GRAPHTRANSFERINFO_DESTINATION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=1358,
)

_GRAPHTRANSFERCONSTNODEINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHTRANSFERNODEINPUTINFO.fields_by_name['node_input'].message_type = _GRAPHTRANSFERNODEINPUT
_GRAPHTRANSFERGRAPHINPUTNODEINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHTRANSFERGRAPHOUTPUTNODEINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHTRANSFERINFO.fields_by_name['node_info'].message_type = _GRAPHTRANSFERNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['const_node_info'].message_type = _GRAPHTRANSFERCONSTNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['node_input_info'].message_type = _GRAPHTRANSFERNODEINPUTINFO
_GRAPHTRANSFERINFO.fields_by_name['node_output_info'].message_type = _GRAPHTRANSFERNODEOUTPUTINFO
_GRAPHTRANSFERINFO.fields_by_name['graph_input_node_info'].message_type = _GRAPHTRANSFERGRAPHINPUTNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['graph_output_node_info'].message_type = _GRAPHTRANSFERGRAPHOUTPUTNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['destination'].enum_type = _GRAPHTRANSFERINFO_DESTINATION
_GRAPHTRANSFERINFO_DESTINATION.containing_type = _GRAPHTRANSFERINFO
DESCRIPTOR.message_types_by_name['GraphTransferNodeInput'] = _GRAPHTRANSFERNODEINPUT
DESCRIPTOR.message_types_by_name['GraphTransferNodeInfo'] = _GRAPHTRANSFERNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferConstNodeInfo'] = _GRAPHTRANSFERCONSTNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferNodeInputInfo'] = _GRAPHTRANSFERNODEINPUTINFO
DESCRIPTOR.message_types_by_name['GraphTransferNodeOutputInfo'] = _GRAPHTRANSFERNODEOUTPUTINFO
DESCRIPTOR.message_types_by_name['GraphTransferGraphInputNodeInfo'] = _GRAPHTRANSFERGRAPHINPUTNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferGraphOutputNodeInfo'] = _GRAPHTRANSFERGRAPHOUTPUTNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferInfo'] = _GRAPHTRANSFERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GraphTransferNodeInput = _reflection.GeneratedProtocolMessageType('GraphTransferNodeInput', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERNODEINPUT,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferNodeInput)
  ))
_sym_db.RegisterMessage(GraphTransferNodeInput)

GraphTransferNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferNodeInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERNODEINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferNodeInfo)
  ))
_sym_db.RegisterMessage(GraphTransferNodeInfo)

GraphTransferConstNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferConstNodeInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERCONSTNODEINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferConstNodeInfo)
  ))
_sym_db.RegisterMessage(GraphTransferConstNodeInfo)

GraphTransferNodeInputInfo = _reflection.GeneratedProtocolMessageType('GraphTransferNodeInputInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERNODEINPUTINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferNodeInputInfo)
  ))
_sym_db.RegisterMessage(GraphTransferNodeInputInfo)

GraphTransferNodeOutputInfo = _reflection.GeneratedProtocolMessageType('GraphTransferNodeOutputInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERNODEOUTPUTINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferNodeOutputInfo)
  ))
_sym_db.RegisterMessage(GraphTransferNodeOutputInfo)

GraphTransferGraphInputNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferGraphInputNodeInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERGRAPHINPUTNODEINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferGraphInputNodeInfo)
  ))
_sym_db.RegisterMessage(GraphTransferGraphInputNodeInfo)

GraphTransferGraphOutputNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferGraphOutputNodeInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERGRAPHOUTPUTNODEINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferGraphOutputNodeInfo)
  ))
_sym_db.RegisterMessage(GraphTransferGraphOutputNodeInfo)

GraphTransferInfo = _reflection.GeneratedProtocolMessageType('GraphTransferInfo', (_message.Message,), dict(
  DESCRIPTOR = _GRAPHTRANSFERINFO,
  __module__ = 'tensorflow.core.framework.graph_transfer_info_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.GraphTransferInfo)
  ))
_sym_db.RegisterMessage(GraphTransferInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\030org.tensorflow.frameworkB\026GraphTransferInfoProtoP\001Z=github.com/tensorflow/tensorflow/tensorflow/go/core/framework\370\001\001'))
# @@protoc_insertion_point(module_scope)



# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/tools/api/generator/create_python_api.py script.
"""Keras built-in datasets.
"""

from __future__ import print_function

from . import boston_housing
from . import cifar10
from . import cifar100
from . import fashion_mnist
from . import imdb
from . import mnist
from . import reuters

del print_function



"""Python wrappers around TensorFlow ops.

This file is MACHINE GENERATED! Do not edit.
Original C++ source file: spectral_ops.cc
"""

import collections as _collections
import six as _six

from tensorflow.python import pywrap_tensorflow as _pywrap_tensorflow
from tensorflow.python.eager import context as _context
from tensorflow.python.eager import core as _core
from tensorflow.python.eager import execute as _execute
from tensorflow.python.framework import dtypes as _dtypes
from tensorflow.python.framework import errors as _errors
from tensorflow.python.framework import tensor_shape as _tensor_shape

from tensorflow.core.framework import op_def_pb2 as _op_def_pb2
# Needed to trigger the call to _set_call_cpp_shape_fn.
from tensorflow.python.framework import common_shapes as _common_shapes
from tensorflow.python.framework import op_def_registry as _op_def_registry
from tensorflow.python.framework import ops as _ops
from tensorflow.python.framework import op_def_library as _op_def_library
from tensorflow.python.util.tf_export import tf_export


def batch_fft(input, name=None):
  r"""TODO: add doc.

  Args:
    input: A `Tensor` of type `complex64`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "BatchFFT", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "BatchFFT", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "BatchFFT",
        name, _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return batch_fft_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def batch_fft_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function batch_fft
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = None
  _result = _execute.execute(b"BatchFFT", 1, inputs=_inputs_flat,
                             attrs=_attrs, ctx=_ctx, name=name)
  _execute.record_gradient(
      "BatchFFT", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def batch_fft2d(input, name=None):
  r"""TODO: add doc.

  Args:
    input: A `Tensor` of type `complex64`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "BatchFFT2D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "BatchFFT2D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "BatchFFT2D",
        name, _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return batch_fft2d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def batch_fft2d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function batch_fft2d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = None
  _result = _execute.execute(b"BatchFFT2D", 1, inputs=_inputs_flat,
                             attrs=_attrs, ctx=_ctx, name=name)
  _execute.record_gradient(
      "BatchFFT2D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def batch_fft3d(input, name=None):
  r"""TODO: add doc.

  Args:
    input: A `Tensor` of type `complex64`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "BatchFFT3D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "BatchFFT3D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "BatchFFT3D",
        name, _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return batch_fft3d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def batch_fft3d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function batch_fft3d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = None
  _result = _execute.execute(b"BatchFFT3D", 1, inputs=_inputs_flat,
                             attrs=_attrs, ctx=_ctx, name=name)
  _execute.record_gradient(
      "BatchFFT3D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def batch_ifft(input, name=None):
  r"""TODO: add doc.

  Args:
    input: A `Tensor` of type `complex64`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "BatchIFFT", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "BatchIFFT", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "BatchIFFT",
        name, _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return batch_ifft_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def batch_ifft_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function batch_ifft
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = None
  _result = _execute.execute(b"BatchIFFT", 1, inputs=_inputs_flat,
                             attrs=_attrs, ctx=_ctx, name=name)
  _execute.record_gradient(
      "BatchIFFT", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def batch_ifft2d(input, name=None):
  r"""TODO: add doc.

  Args:
    input: A `Tensor` of type `complex64`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "BatchIFFT2D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "BatchIFFT2D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "BatchIFFT2D",
        name, _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return batch_ifft2d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def batch_ifft2d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function batch_ifft2d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = None
  _result = _execute.execute(b"BatchIFFT2D", 1, inputs=_inputs_flat,
                             attrs=_attrs, ctx=_ctx, name=name)
  _execute.record_gradient(
      "BatchIFFT2D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def batch_ifft3d(input, name=None):
  r"""TODO: add doc.

  Args:
    input: A `Tensor` of type `complex64`.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "BatchIFFT3D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "BatchIFFT3D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "BatchIFFT3D",
        name, _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return batch_ifft3d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def batch_ifft3d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function batch_ifft3d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = None
  _result = _execute.execute(b"BatchIFFT3D", 1, inputs=_inputs_flat,
                             attrs=_attrs, ctx=_ctx, name=name)
  _execute.record_gradient(
      "BatchIFFT3D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


@tf_export('fft', 'spectral.fft')
def fft(input, name=None):
  r"""Fast Fourier transform.

  Computes the 1-dimensional discrete Fourier transform over the inner-most
  dimension of `input`.

  Args:
    input: A `Tensor`. Must be one of the following types: `complex64`, `complex128`.
      A complex64 tensor.
    name: A name for the operation (optional).

  Returns:
    A `Tensor`. Has the same type as `input`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "FFT", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = ("Tcomplex", _op.get_attr("Tcomplex"))
    _execute.record_gradient(
      "FFT", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "FFT", name,
        _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return fft_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def fft_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function fft
  """
  _ctx = ctx if ctx else _context.context()
  _attr_Tcomplex, (input,) = _execute.args_to_matching_eager([input], _ctx, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = ("Tcomplex", _attr_Tcomplex)
  _result = _execute.execute(b"FFT", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "FFT", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


@tf_export('spectral.fft2d', 'fft2d')
def fft2d(input, name=None):
  r"""2D fast Fourier transform.

  Computes the 2-dimensional discrete Fourier transform over the inner-most
  2 dimensions of `input`.

  Args:
    input: A `Tensor`. Must be one of the following types: `complex64`, `complex128`.
      A complex64 tensor.
    name: A name for the operation (optional).

  Returns:
    A `Tensor`. Has the same type as `input`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "FFT2D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = ("Tcomplex", _op.get_attr("Tcomplex"))
    _execute.record_gradient(
      "FFT2D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "FFT2D", name,
        _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return fft2d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def fft2d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function fft2d
  """
  _ctx = ctx if ctx else _context.context()
  _attr_Tcomplex, (input,) = _execute.args_to_matching_eager([input], _ctx, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = ("Tcomplex", _attr_Tcomplex)
  _result = _execute.execute(b"FFT2D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "FFT2D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


@tf_export('spectral.fft3d', 'fft3d')
def fft3d(input, name=None):
  r"""3D fast Fourier transform.

  Computes the 3-dimensional discrete Fourier transform over the inner-most 3
  dimensions of `input`.

  Args:
    input: A `Tensor`. Must be one of the following types: `complex64`, `complex128`.
      A complex64 tensor.
    name: A name for the operation (optional).

  Returns:
    A `Tensor`. Has the same type as `input`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "FFT3D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = ("Tcomplex", _op.get_attr("Tcomplex"))
    _execute.record_gradient(
      "FFT3D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "FFT3D", name,
        _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return fft3d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def fft3d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function fft3d
  """
  _ctx = ctx if ctx else _context.context()
  _attr_Tcomplex, (input,) = _execute.args_to_matching_eager([input], _ctx, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = ("Tcomplex", _attr_Tcomplex)
  _result = _execute.execute(b"FFT3D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "FFT3D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


@tf_export('ifft', 'spectral.ifft')
def ifft(input, name=None):
  r"""Inverse fast Fourier transform.

  Computes the inverse 1-dimensional discrete Fourier transform over the
  inner-most dimension of `input`.

  Args:
    input: A `Tensor`. Must be one of the following types: `complex64`, `complex128`.
      A complex64 tensor.
    name: A name for the operation (optional).

  Returns:
    A `Tensor`. Has the same type as `input`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "IFFT", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = ("Tcomplex", _op.get_attr("Tcomplex"))
    _execute.record_gradient(
      "IFFT", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "IFFT", name,
        _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return ifft_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def ifft_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function ifft
  """
  _ctx = ctx if ctx else _context.context()
  _attr_Tcomplex, (input,) = _execute.args_to_matching_eager([input], _ctx, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = ("Tcomplex", _attr_Tcomplex)
  _result = _execute.execute(b"IFFT", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "IFFT", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


@tf_export('spectral.ifft2d', 'ifft2d')
def ifft2d(input, name=None):
  r"""Inverse 2D fast Fourier transform.

  Computes the inverse 2-dimensional discrete Fourier transform over the
  inner-most 2 dimensions of `input`.

  Args:
    input: A `Tensor`. Must be one of the following types: `complex64`, `complex128`.
      A complex64 tensor.
    name: A name for the operation (optional).

  Returns:
    A `Tensor`. Has the same type as `input`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "IFFT2D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = ("Tcomplex", _op.get_attr("Tcomplex"))
    _execute.record_gradient(
      "IFFT2D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "IFFT2D", name,
        _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return ifft2d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def ifft2d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function ifft2d
  """
  _ctx = ctx if ctx else _context.context()
  _attr_Tcomplex, (input,) = _execute.args_to_matching_eager([input], _ctx, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = ("Tcomplex", _attr_Tcomplex)
  _result = _execute.execute(b"IFFT2D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "IFFT2D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


@tf_export('spectral.ifft3d', 'ifft3d')
def ifft3d(input, name=None):
  r"""Inverse 3D fast Fourier transform.

  Computes the inverse 3-dimensional discrete Fourier transform over the
  inner-most 3 dimensions of `input`.

  Args:
    input: A `Tensor`. Must be one of the following types: `complex64`, `complex128`.
      A complex64 tensor.
    name: A name for the operation (optional).

  Returns:
    A `Tensor`. Has the same type as `input`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "IFFT3D", input=input, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = ("Tcomplex", _op.get_attr("Tcomplex"))
    _execute.record_gradient(
      "IFFT3D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "IFFT3D", name,
        _ctx._post_execution_callbacks, input)
      return _result
    except _core._FallbackException:
      return ifft3d_eager_fallback(
          input, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def ifft3d_eager_fallback(input, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function ifft3d
  """
  _ctx = ctx if ctx else _context.context()
  _attr_Tcomplex, (input,) = _execute.args_to_matching_eager([input], _ctx, _dtypes.complex64)
  _inputs_flat = [input]
  _attrs = ("Tcomplex", _attr_Tcomplex)
  _result = _execute.execute(b"IFFT3D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "IFFT3D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def irfft(input, fft_length, name=None):
  r"""Inverse real-valued fast Fourier transform.

  Computes the inverse 1-dimensional discrete Fourier transform of a real-valued
  signal over the inner-most dimension of `input`.

  The inner-most dimension of `input` is assumed to be the result of `RFFT`: the
  `fft_length / 2 + 1` unique components of the DFT of a real-valued signal. If
  `fft_length` is not provided, it is computed from the size of the inner-most
  dimension of `input` (`fft_length = 2 * (inner - 1)`). If the FFT length used to
  compute `input` is odd, it should be provided since it cannot be inferred
  properly.

  Along the axis `IRFFT` is computed on, if `fft_length / 2 + 1` is smaller
  than the corresponding dimension of `input`, the dimension is cropped. If it is
  larger, the dimension is padded with zeros.

  Args:
    input: A `Tensor` of type `complex64`. A complex64 tensor.
    fft_length: A `Tensor` of type `int32`.
      An int32 tensor of shape [1]. The FFT length.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `float32`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "IRFFT", input=input, fft_length=fft_length, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "IRFFT", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "IRFFT", name,
        _ctx._post_execution_callbacks, input, fft_length)
      return _result
    except _core._FallbackException:
      return irfft_eager_fallback(
          input, fft_length, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def irfft_eager_fallback(input, fft_length, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function irfft
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  fft_length = _ops.convert_to_tensor(fft_length, _dtypes.int32)
  _inputs_flat = [input, fft_length]
  _attrs = None
  _result = _execute.execute(b"IRFFT", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "IRFFT", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def irfft2d(input, fft_length, name=None):
  r"""Inverse 2D real-valued fast Fourier transform.

  Computes the inverse 2-dimensional discrete Fourier transform of a real-valued
  signal over the inner-most 2 dimensions of `input`.

  The inner-most 2 dimensions of `input` are assumed to be the result of `RFFT2D`:
  The inner-most dimension contains the `fft_length / 2 + 1` unique components of
  the DFT of a real-valued signal. If `fft_length` is not provided, it is computed
  from the size of the inner-most 2 dimensions of `input`. If the FFT length used
  to compute `input` is odd, it should be provided since it cannot be inferred
  properly.

  Along each axis `IRFFT2D` is computed on, if `fft_length` (or
  `fft_length / 2 + 1` for the inner-most dimension) is smaller than the
  corresponding dimension of `input`, the dimension is cropped. If it is larger,
  the dimension is padded with zeros.

  Args:
    input: A `Tensor` of type `complex64`. A complex64 tensor.
    fft_length: A `Tensor` of type `int32`.
      An int32 tensor of shape [2]. The FFT length for each dimension.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `float32`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "IRFFT2D", input=input, fft_length=fft_length, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "IRFFT2D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "IRFFT2D",
        name, _ctx._post_execution_callbacks, input, fft_length)
      return _result
    except _core._FallbackException:
      return irfft2d_eager_fallback(
          input, fft_length, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def irfft2d_eager_fallback(input, fft_length, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function irfft2d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  fft_length = _ops.convert_to_tensor(fft_length, _dtypes.int32)
  _inputs_flat = [input, fft_length]
  _attrs = None
  _result = _execute.execute(b"IRFFT2D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "IRFFT2D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def irfft3d(input, fft_length, name=None):
  r"""Inverse 3D real-valued fast Fourier transform.

  Computes the inverse 3-dimensional discrete Fourier transform of a real-valued
  signal over the inner-most 3 dimensions of `input`.

  The inner-most 3 dimensions of `input` are assumed to be the result of `RFFT3D`:
  The inner-most dimension contains the `fft_length / 2 + 1` unique components of
  the DFT of a real-valued signal. If `fft_length` is not provided, it is computed
  from the size of the inner-most 3 dimensions of `input`. If the FFT length used
  to compute `input` is odd, it should be provided since it cannot be inferred
  properly.

  Along each axis `IRFFT3D` is computed on, if `fft_length` (or
  `fft_length / 2 + 1` for the inner-most dimension) is smaller than the
  corresponding dimension of `input`, the dimension is cropped. If it is larger,
  the dimension is padded with zeros.

  Args:
    input: A `Tensor` of type `complex64`. A complex64 tensor.
    fft_length: A `Tensor` of type `int32`.
      An int32 tensor of shape [3]. The FFT length for each dimension.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `float32`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "IRFFT3D", input=input, fft_length=fft_length, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "IRFFT3D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "IRFFT3D",
        name, _ctx._post_execution_callbacks, input, fft_length)
      return _result
    except _core._FallbackException:
      return irfft3d_eager_fallback(
          input, fft_length, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def irfft3d_eager_fallback(input, fft_length, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function irfft3d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.complex64)
  fft_length = _ops.convert_to_tensor(fft_length, _dtypes.int32)
  _inputs_flat = [input, fft_length]
  _attrs = None
  _result = _execute.execute(b"IRFFT3D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "IRFFT3D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def rfft(input, fft_length, name=None):
  r"""Real-valued fast Fourier transform.

  Computes the 1-dimensional discrete Fourier transform of a real-valued signal
  over the inner-most dimension of `input`.

  Since the DFT of a real signal is Hermitian-symmetric, `RFFT` only returns the
  `fft_length / 2 + 1` unique components of the FFT: the zero-frequency term,
  followed by the `fft_length / 2` positive-frequency terms.

  Along the axis `RFFT` is computed on, if `fft_length` is smaller than the
  corresponding dimension of `input`, the dimension is cropped. If it is larger,
  the dimension is padded with zeros.

  Args:
    input: A `Tensor` of type `float32`. A float32 tensor.
    fft_length: A `Tensor` of type `int32`.
      An int32 tensor of shape [1]. The FFT length.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "RFFT", input=input, fft_length=fft_length, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "RFFT", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "RFFT", name,
        _ctx._post_execution_callbacks, input, fft_length)
      return _result
    except _core._FallbackException:
      return rfft_eager_fallback(
          input, fft_length, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def rfft_eager_fallback(input, fft_length, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function rfft
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.float32)
  fft_length = _ops.convert_to_tensor(fft_length, _dtypes.int32)
  _inputs_flat = [input, fft_length]
  _attrs = None
  _result = _execute.execute(b"RFFT", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "RFFT", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def rfft2d(input, fft_length, name=None):
  r"""2D real-valued fast Fourier transform.

  Computes the 2-dimensional discrete Fourier transform of a real-valued signal
  over the inner-most 2 dimensions of `input`.

  Since the DFT of a real signal is Hermitian-symmetric, `RFFT2D` only returns the
  `fft_length / 2 + 1` unique components of the FFT for the inner-most dimension
  of `output`: the zero-frequency term, followed by the `fft_length / 2`
  positive-frequency terms.

  Along each axis `RFFT2D` is computed on, if `fft_length` is smaller than the
  corresponding dimension of `input`, the dimension is cropped. If it is larger,
  the dimension is padded with zeros.

  Args:
    input: A `Tensor` of type `float32`. A float32 tensor.
    fft_length: A `Tensor` of type `int32`.
      An int32 tensor of shape [2]. The FFT length for each dimension.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "RFFT2D", input=input, fft_length=fft_length, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "RFFT2D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "RFFT2D", name,
        _ctx._post_execution_callbacks, input, fft_length)
      return _result
    except _core._FallbackException:
      return rfft2d_eager_fallback(
          input, fft_length, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def rfft2d_eager_fallback(input, fft_length, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function rfft2d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.float32)
  fft_length = _ops.convert_to_tensor(fft_length, _dtypes.int32)
  _inputs_flat = [input, fft_length]
  _attrs = None
  _result = _execute.execute(b"RFFT2D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "RFFT2D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result


def rfft3d(input, fft_length, name=None):
  r"""3D real-valued fast Fourier transform.

  Computes the 3-dimensional discrete Fourier transform of a real-valued signal
  over the inner-most 3 dimensions of `input`.

  Since the DFT of a real signal is Hermitian-symmetric, `RFFT3D` only returns the
  `fft_length / 2 + 1` unique components of the FFT for the inner-most dimension
  of `output`: the zero-frequency term, followed by the `fft_length / 2`
  positive-frequency terms.

  Along each axis `RFFT3D` is computed on, if `fft_length` is smaller than the
  corresponding dimension of `input`, the dimension is cropped. If it is larger,
  the dimension is padded with zeros.

  Args:
    input: A `Tensor` of type `float32`. A float32 tensor.
    fft_length: A `Tensor` of type `int32`.
      An int32 tensor of shape [3]. The FFT length for each dimension.
    name: A name for the operation (optional).

  Returns:
    A `Tensor` of type `complex64`.
  """
  _ctx = _context._context
  if _ctx is None or not _ctx._eager_context.is_eager:
    _, _, _op = _op_def_lib._apply_op_helper(
        "RFFT3D", input=input, fft_length=fft_length, name=name)
    _result = _op.outputs[:]
    _inputs_flat = _op.inputs
    _attrs = None
    _execute.record_gradient(
      "RFFT3D", _inputs_flat, _attrs, _result, name)
    _result, = _result
    return _result

  else:
    try:
      _result = _pywrap_tensorflow.TFE_Py_FastPathExecute(
        _ctx._context_handle, _ctx._eager_context.device_name, "RFFT3D", name,
        _ctx._post_execution_callbacks, input, fft_length)
      return _result
    except _core._FallbackException:
      return rfft3d_eager_fallback(
          input, fft_length, name=name, ctx=_ctx)
    except _core._NotOkStatusException as e:
      if name is not None:
        message = e.message + " name: " + name
      else:
        message = e.message
      _six.raise_from(_core._status_to_exception(e.code, message), None)


def rfft3d_eager_fallback(input, fft_length, name=None, ctx=None):
  r"""This is the slowpath function for Eager mode.
  This is for function rfft3d
  """
  _ctx = ctx if ctx else _context.context()
  input = _ops.convert_to_tensor(input, _dtypes.float32)
  fft_length = _ops.convert_to_tensor(fft_length, _dtypes.int32)
  _inputs_flat = [input, fft_length]
  _attrs = None
  _result = _execute.execute(b"RFFT3D", 1, inputs=_inputs_flat, attrs=_attrs,
                             ctx=_ctx, name=name)
  _execute.record_gradient(
      "RFFT3D", _inputs_flat, _attrs, _result, name)
  _result, = _result
  return _result

def _InitOpDefLibrary(op_list_proto_bytes):
  op_list = _op_def_pb2.OpList()
  op_list.ParseFromString(op_list_proto_bytes)
  _op_def_registry.register_op_list(op_list)
  op_def_lib = _op_def_library.OpDefLibrary()
  op_def_lib.add_op_list(op_list)
  return op_def_lib
# op {
#   name: "BatchFFT"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
#   deprecation {
#     version: 15
#     explanation: "Use FFT"
#   }
# }
# op {
#   name: "BatchFFT2D"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
#   deprecation {
#     version: 15
#     explanation: "Use FFT2D"
#   }
# }
# op {
#   name: "BatchFFT3D"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
#   deprecation {
#     version: 15
#     explanation: "Use FFT3D"
#   }
# }
# op {
#   name: "BatchIFFT"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
#   deprecation {
#     version: 15
#     explanation: "Use IFFT"
#   }
# }
# op {
#   name: "BatchIFFT2D"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
#   deprecation {
#     version: 15
#     explanation: "Use IFFT2D"
#   }
# }
# op {
#   name: "BatchIFFT3D"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
#   deprecation {
#     version: 15
#     explanation: "Use IFFT3D"
#   }
# }
# op {
#   name: "FFT"
#   input_arg {
#     name: "input"
#     type_attr: "Tcomplex"
#   }
#   output_arg {
#     name: "output"
#     type_attr: "Tcomplex"
#   }
#   attr {
#     name: "Tcomplex"
#     type: "type"
#     default_value {
#       type: DT_COMPLEX64
#     }
#     allowed_values {
#       list {
#         type: DT_COMPLEX64
#         type: DT_COMPLEX128
#       }
#     }
#   }
# }
# op {
#   name: "FFT2D"
#   input_arg {
#     name: "input"
#     type_attr: "Tcomplex"
#   }
#   output_arg {
#     name: "output"
#     type_attr: "Tcomplex"
#   }
#   attr {
#     name: "Tcomplex"
#     type: "type"
#     default_value {
#       type: DT_COMPLEX64
#     }
#     allowed_values {
#       list {
#         type: DT_COMPLEX64
#         type: DT_COMPLEX128
#       }
#     }
#   }
# }
# op {
#   name: "FFT3D"
#   input_arg {
#     name: "input"
#     type_attr: "Tcomplex"
#   }
#   output_arg {
#     name: "output"
#     type_attr: "Tcomplex"
#   }
#   attr {
#     name: "Tcomplex"
#     type: "type"
#     default_value {
#       type: DT_COMPLEX64
#     }
#     allowed_values {
#       list {
#         type: DT_COMPLEX64
#         type: DT_COMPLEX128
#       }
#     }
#   }
# }
# op {
#   name: "IFFT"
#   input_arg {
#     name: "input"
#     type_attr: "Tcomplex"
#   }
#   output_arg {
#     name: "output"
#     type_attr: "Tcomplex"
#   }
#   attr {
#     name: "Tcomplex"
#     type: "type"
#     default_value {
#       type: DT_COMPLEX64
#     }
#     allowed_values {
#       list {
#         type: DT_COMPLEX64
#         type: DT_COMPLEX128
#       }
#     }
#   }
# }
# op {
#   name: "IFFT2D"
#   input_arg {
#     name: "input"
#     type_attr: "Tcomplex"
#   }
#   output_arg {
#     name: "output"
#     type_attr: "Tcomplex"
#   }
#   attr {
#     name: "Tcomplex"
#     type: "type"
#     default_value {
#       type: DT_COMPLEX64
#     }
#     allowed_values {
#       list {
#         type: DT_COMPLEX64
#         type: DT_COMPLEX128
#       }
#     }
#   }
# }
# op {
#   name: "IFFT3D"
#   input_arg {
#     name: "input"
#     type_attr: "Tcomplex"
#   }
#   output_arg {
#     name: "output"
#     type_attr: "Tcomplex"
#   }
#   attr {
#     name: "Tcomplex"
#     type: "type"
#     default_value {
#       type: DT_COMPLEX64
#     }
#     allowed_values {
#       list {
#         type: DT_COMPLEX64
#         type: DT_COMPLEX128
#       }
#     }
#   }
# }
# op {
#   name: "IRFFT"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   input_arg {
#     name: "fft_length"
#     type: DT_INT32
#   }
#   output_arg {
#     name: "output"
#     type: DT_FLOAT
#   }
# }
# op {
#   name: "IRFFT2D"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   input_arg {
#     name: "fft_length"
#     type: DT_INT32
#   }
#   output_arg {
#     name: "output"
#     type: DT_FLOAT
#   }
# }
# op {
#   name: "IRFFT3D"
#   input_arg {
#     name: "input"
#     type: DT_COMPLEX64
#   }
#   input_arg {
#     name: "fft_length"
#     type: DT_INT32
#   }
#   output_arg {
#     name: "output"
#     type: DT_FLOAT
#   }
# }
# op {
#   name: "RFFT"
#   input_arg {
#     name: "input"
#     type: DT_FLOAT
#   }
#   input_arg {
#     name: "fft_length"
#     type: DT_INT32
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
# }
# op {
#   name: "RFFT2D"
#   input_arg {
#     name: "input"
#     type: DT_FLOAT
#   }
#   input_arg {
#     name: "fft_length"
#     type: DT_INT32
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
# }
# op {
#   name: "RFFT3D"
#   input_arg {
#     name: "input"
#     type: DT_FLOAT
#   }
#   input_arg {
#     name: "fft_length"
#     type: DT_INT32
#   }
#   output_arg {
#     name: "output"
#     type: DT_COMPLEX64
#   }
# }
_op_def_lib = _InitOpDefLibrary(b"\n.\n\010BatchFFT\022\t\n\005input\030\010\032\n\n\006output\030\010B\013\010\017\022\007Use FFT\n2\n\nBatchFFT2D\022\t\n\005input\030\010\032\n\n\006output\030\010B\r\010\017\022\tUse FFT2D\n2\n\nBatchFFT3D\022\t\n\005input\030\010\032\n\n\006output\030\010B\r\010\017\022\tUse FFT3D\n0\n\tBatchIFFT\022\t\n\005input\030\010\032\n\n\006output\030\010B\014\010\017\022\010Use IFFT\n4\n\013BatchIFFT2D\022\t\n\005input\030\010\032\n\n\006output\030\010B\016\010\017\022\nUse IFFT2D\n4\n\013BatchIFFT3D\022\t\n\005input\030\010\032\n\n\006output\030\010B\016\010\017\022\nUse IFFT3D\nJ\n\003FFT\022\021\n\005input\"\010Tcomplex\032\022\n\006output\"\010Tcomplex\"\034\n\010Tcomplex\022\004type\032\0020\010:\006\n\0042\002\010\022\nL\n\005FFT2D\022\021\n\005input\"\010Tcomplex\032\022\n\006output\"\010Tcomplex\"\034\n\010Tcomplex\022\004type\032\0020\010:\006\n\0042\002\010\022\nL\n\005FFT3D\022\021\n\005input\"\010Tcomplex\032\022\n\006output\"\010Tcomplex\"\034\n\010Tcomplex\022\004type\032\0020\010:\006\n\0042\002\010\022\nK\n\004IFFT\022\021\n\005input\"\010Tcomplex\032\022\n\006output\"\010Tcomplex\"\034\n\010Tcomplex\022\004type\032\0020\010:\006\n\0042\002\010\022\nM\n\006IFFT2D\022\021\n\005input\"\010Tcomplex\032\022\n\006output\"\010Tcomplex\"\034\n\010Tcomplex\022\004type\032\0020\010:\006\n\0042\002\010\022\nM\n\006IFFT3D\022\021\n\005input\"\010Tcomplex\032\022\n\006output\"\010Tcomplex\"\034\n\010Tcomplex\022\004type\032\0020\010:\006\n\0042\002\010\022\n.\n\005IRFFT\022\t\n\005input\030\010\022\016\n\nfft_length\030\003\032\n\n\006output\030\001\n0\n\007IRFFT2D\022\t\n\005input\030\010\022\016\n\nfft_length\030\003\032\n\n\006output\030\001\n0\n\007IRFFT3D\022\t\n\005input\030\010\022\016\n\nfft_length\030\003\032\n\n\006output\030\001\n-\n\004RFFT\022\t\n\005input\030\001\022\016\n\nfft_length\030\003\032\n\n\006output\030\010\n/\n\006RFFT2D\022\t\n\005input\030\001\022\016\n\nfft_length\030\003\032\n\n\006output\030\010\n/\n\006RFFT3D\022\t\n\005input\030\001\022\016\n\nfft_length\030\003\032\n\n\006output\030\010")
